#! /usr/bin/sh
#set -x
#for name in scotch_acpl scotch_amk_ccc scotch_amk_fft2 scotch_amk_grf scotch_amk_hy scotch_amk_m2 scotch_amk_p2 scotch_atst scotch_gbase scotch_gcv scotch_gmap scotch_gmk_hy scotch_gmk_m2 scotch_gmk_m3 scotch_gmk_msh scotch_gmk_ub2 scotch_gmtst scotch_gord scotch_gotst scotch_gout scotch_gtst scotch_mcv scotch_mmk_m2 scotch_mmk_m3 scotch_mord scotch_mtst scotch_esmumps; do
for name in scotch_esmumps ptscotch_esmumps; do

manname=`echo -n ${name}.1`
cat > $manname <<EOF
.\" -*- nroff -*-
.TH $name 1 "April 2009" "Scotch"
.SH NAME
$name \- scotch command
.SH SYNOPSIS
.B $name
.br
.SH DESCRIPTION
This manual page documents briefly the
.BR $name
command.

You can find information in the scotch manual and on the scotch web
page http://www.labri.fr/perso/pelegrin/scotch/ and project page
http://gforge.inria.fr/projects/scotch/.

.SH AUTHOR
The Debian Scientific Computing Team
EOF
echo debian/$manname /usr/share/man/man1
done

